@@ -18,12 +18,12 @@ test_expect_success 'Fork stack off parent branch, and add patches to the stack'
 
 test_expect_success 'Test invalid remote argument' '
     command_error stg pull origin 2>err &&
-    grep "Specifying a repository is meaningless for \`rebase\` pull-policy" err
+    grep "specifying a repository is meaningless for \`rebase\` pull-policy" err
 '
 
 test_expect_success 'Test invalid arguments' '
     general_error stg pull origin master 2>err &&
-    grep "Found argument .master. which wasn.t expected" err
+    grep "unexpected argument .master." err
 '
 
 test_expect_success 'Add non-rewinding commit in parent and pull the stack' '
